import requests
import threading
import time
import json
from strings import wp_plugins1, wp_plugins2
from .. import NotWordpress, SiteNotFound, UsersFileNotFound, NotFoundData

plugins_list = []
counter = 0


class Wordpress:

    def __init__(self):
        pass

    async def wp_checker(self, domain: str):
        if 'http://' in domain:
            domain = domain.replace('http://', '')
        elif 'https://' in domain:
            domain = domain.replace('https://', '')
        else:
            domain = domain
        try:
            s = requests.get("http://"+domain+"/wp-content/plugins/")
            if s.history:
                return False
        except requests.exceptions.ConnectionError:
            return False
        if s.status_code == 404 or s.status_code == 500:
            return False
        return True

    async def user(self, domain: str):
        try:
            if 'http://' in domain:
                domain = domain.replace('http://', '')
            elif 'https://' in domain:
                domain = domain.replace('https://', '')
            else:
                domain = domain
            if not await self.wp_checker(domain):
                raise NotWordpress(domain)
        except:
            pass
        try:
            r = requests.get("https://"+domain+'/wp-json/wp/v2/users/').text
            j = json.loads(r)
            Count = len(j) - 1
            users_list = []
            cn = 0
            User = ''
            for Val in j:
                Split = '\n'
                if Count == cn:
                    Split = ''
                U = j[cn]['slug']
                if not U == '':
                    User += U+Split
                cn += 1
            if User == '':
                User = 'Not Found!'
            return User
        except json.decoder.JSONDecodeError:
            raise NotWordpress(domain)
        except requests.exceptions.ConnectionError:
            raise SiteNotFound(domain)
        except KeyError:
            raise UsersFileNotFound
        except Exception as e:
            raise e

    def send_request(self, plugins: list, url: str):
        global plugins_list
        global counter
        for plus in plugins:
            counter += 1
            time.sleep(0.1)
            try:
                r = requests.get(f"http://{url}/wp-content/plugins/{plus}")
                if r.status_code == 200:
                    plugins_list.append(
                        f"http://{url}/wp-content/plugins/{plus}")
                else:
                    pass
            except Exception as e:
                print(counter)

    def main(self, url: str):
        if not self.wp_checker(url):
            return 'not wp'
        if 'http://' in url:
            url = url.replace('http://', '')
        elif 'https://' in url:
            url = url.replace('https://', '')
        else:
            url = url
        t1 = threading.Thread(target=self.send_request,
                              args=(wp_plugins1, url))
        t2 = threading.Thread(target=self.send_request,
                              args=(wp_plugins2, url))
        t1.start()
        t2.start()
        t1.join()
        t2.join()
        global plugins_list
        if plugins_list == []:
            raise NotFoundData

        else: return plugins_list


from strings import aspx_login, asp_login, php_login, html_login, cgi_login, brf_login, cfm_login, js_login, \
    slash_login, ua
import requests
import random


class BruteForcer:

    def __init__(self) -> None:
        pass

    def admin(self, domain: str, timeout: int = 10, ext: str = "php", user_agent: str | None = None,
              cookie: str | None = None, proxy: str | None = None, proxies: list | None = None):

        if "http://" in domain:
            domain = domain.replace("http://", "")
        elif "https://" in domain:
            domain = domain.replace("https://", "")
        else:
            pass
        domain = "http://" + domain

        links = []
        ext = ext.strip().lower()
        if ext == "php":
            links = php_login
        elif ext == "asp":
            links = asp_login
        elif ext == "aspx":
            links = aspx_login
        elif ext == "js":
            links = js_login
        elif ext == "/":
            links = slash_login
        elif ext == "cfm":
            links = cfm_login
        elif ext == "cgi":
            links = cgi_login
        elif ext == "brf":
            links = brf_login
        elif ext == "html":
            links = html_login
        else:
            raise ValueError("This ext(Argument) Not Allowed !")

        founded = []
        for i in links:
            try:
                if proxy:
                    proxy = {"http": "http://" + str(proxy), "https": "http://" + str(proxy)}
                if proxies:
                    random_proxy = random.choice(proxies)
                    proxy = {"http": "http://" + str(random_proxy), "https": "http://" + str(random_proxy)}
                if not user_agent:
                    user_agent = random.choice(ua)
                header = {"User-Agent": user_agent}
                if cookie:
                    header.update({"Cookie": cookie})
                if domain[len(domain) - 1] == "/":
                    domain = domain[0: len(domain) - 1]

                full_link = domain + i
                try:
                    if proxy or proxies:
                        r = requests.get(
                            full_link,
                            headers=header,
                            allow_redirects=False,
                            proxies=proxy,
                            timeout=timeout,
                            verify=False,
                        )
                    else:
                        r = requests.get(
                            full_link,
                            headers=header,
                            allow_redirects=False,
                            timeout=timeout,
                            verify=False,
                        )
                except Exception as e:
                    if len(founded) >= 1:
                        result = {domain: founded}
                        return result
                    else:
                        return e
                if r.status_code == 200:
                    founded.append(full_link)
                else:
                    pass
            except KeyboardInterrupt:
                break
        result = {domain: founded}
        return result
